pub enum PackageMarker {
FullLine,
Front,
End,
}Expand description
User-configurable application settings parsed from pacsea.conf.
Variants
FullLine
Color the entire line for the marked package.
Front
Add a marker at the front of the line.
End
Add a marker at the end of the line.