pub struct KeyMap {Show 55 fields
pub help_overlay: Vec<KeyChord>,
pub reload_config: Vec<KeyChord>,
pub exit: Vec<KeyChord>,
pub show_pkgbuild: Vec<KeyChord>,
pub comments_toggle: Vec<KeyChord>,
pub change_sort: Vec<KeyChord>,
pub pane_next: Vec<KeyChord>,
pub pane_left: Vec<KeyChord>,
pub pane_right: Vec<KeyChord>,
pub config_menu_toggle: Vec<KeyChord>,
pub options_menu_toggle: Vec<KeyChord>,
pub panels_menu_toggle: Vec<KeyChord>,
pub search_move_up: Vec<KeyChord>,
pub search_move_down: Vec<KeyChord>,
pub search_page_up: Vec<KeyChord>,
pub search_page_down: Vec<KeyChord>,
pub search_add: Vec<KeyChord>,
pub search_install: Vec<KeyChord>,
pub search_focus_left: Vec<KeyChord>,
pub search_focus_right: Vec<KeyChord>,
pub search_backspace: Vec<KeyChord>,
pub search_insert_clear: Vec<KeyChord>,
pub search_normal_toggle: Vec<KeyChord>,
pub search_normal_insert: Vec<KeyChord>,
pub search_normal_select_left: Vec<KeyChord>,
pub search_normal_select_right: Vec<KeyChord>,
pub search_normal_delete: Vec<KeyChord>,
pub search_normal_clear: Vec<KeyChord>,
pub search_normal_open_status: Vec<KeyChord>,
pub search_normal_import: Vec<KeyChord>,
pub search_normal_export: Vec<KeyChord>,
pub search_normal_updates: Vec<KeyChord>,
pub toggle_fuzzy: Vec<KeyChord>,
pub recent_move_up: Vec<KeyChord>,
pub recent_move_down: Vec<KeyChord>,
pub recent_find: Vec<KeyChord>,
pub recent_use: Vec<KeyChord>,
pub recent_add: Vec<KeyChord>,
pub recent_to_search: Vec<KeyChord>,
pub recent_focus_right: Vec<KeyChord>,
pub recent_remove: Vec<KeyChord>,
pub recent_clear: Vec<KeyChord>,
pub install_move_up: Vec<KeyChord>,
pub install_move_down: Vec<KeyChord>,
pub install_confirm: Vec<KeyChord>,
pub install_remove: Vec<KeyChord>,
pub install_clear: Vec<KeyChord>,
pub install_find: Vec<KeyChord>,
pub install_to_search: Vec<KeyChord>,
pub install_focus_left: Vec<KeyChord>,
pub news_mark_read: Vec<KeyChord>,
pub news_mark_all_read: Vec<KeyChord>,
pub news_mark_read_feed: Vec<KeyChord>,
pub news_mark_unread_feed: Vec<KeyChord>,
pub news_toggle_read_feed: Vec<KeyChord>,
}Expand description
Application key bindings. Each action can have multiple chords.
Fields
help_overlay: Vec<KeyChord>Key chords to show help overlay.
reload_config: Vec<KeyChord>Key chords to reload configuration.
exit: Vec<KeyChord>Key chords to exit the application.
show_pkgbuild: Vec<KeyChord>Global: Show/Hide PKGBUILD viewer
comments_toggle: Vec<KeyChord>Global: Show/Hide AUR comments viewer
change_sort: Vec<KeyChord>Global: Change results sorting mode
pane_next: Vec<KeyChord>Key chords to move to next pane.
pane_left: Vec<KeyChord>Key chords to move focus left.
pane_right: Vec<KeyChord>Key chords to move focus right.
Global: Toggle Config/Lists dropdown
Global: Toggle Options dropdown
Global: Toggle Panels dropdown
search_move_up: Vec<KeyChord>Key chords to move selection up in search results.
search_move_down: Vec<KeyChord>Key chords to move selection down in search results.
search_page_up: Vec<KeyChord>Key chords to page up in search results.
search_page_down: Vec<KeyChord>Key chords to page down in search results.
search_add: Vec<KeyChord>Key chords to add package to install list.
search_install: Vec<KeyChord>Key chords to install selected package.
search_focus_left: Vec<KeyChord>Key chords to move focus left from search pane.
search_focus_right: Vec<KeyChord>Key chords to move focus right from search pane.
search_backspace: Vec<KeyChord>Key chords for backspace in search input.
search_insert_clear: Vec<KeyChord>Insert mode: clear entire search input (default: Shift+Del)
search_normal_toggle: Vec<KeyChord>Toggle Search normal mode on/off (works from both insert/normal)
search_normal_insert: Vec<KeyChord>Enter insert mode while in Search normal mode
search_normal_select_left: Vec<KeyChord>Normal mode: extend selection to the left (default: h)
search_normal_select_right: Vec<KeyChord>Normal mode: extend selection to the right (default: l)
search_normal_delete: Vec<KeyChord>Normal mode: delete selected text (default: d)
search_normal_clear: Vec<KeyChord>Normal mode: clear entire search input (default: Shift+Del)
search_normal_open_status: Vec<KeyChord>Normal mode: open Arch status page in browser (default: Shift+S)
search_normal_import: Vec<KeyChord>Normal mode: trigger Import packages dialog
search_normal_export: Vec<KeyChord>Normal mode: trigger Export Install list
search_normal_updates: Vec<KeyChord>Normal mode: open Available Updates window
toggle_fuzzy: Vec<KeyChord>Toggle fuzzy search mode on/off
recent_move_up: Vec<KeyChord>Key chords to move selection up in recent queries.
recent_move_down: Vec<KeyChord>Key chords to move selection down in recent queries.
recent_find: Vec<KeyChord>Key chords to find/search in recent queries.
recent_use: Vec<KeyChord>Key chords to use selected recent query.
recent_add: Vec<KeyChord>Key chords to add package from recent to install list.
recent_to_search: Vec<KeyChord>Key chords to move focus from recent to search pane.
recent_focus_right: Vec<KeyChord>Key chords to move focus right from recent pane.
recent_remove: Vec<KeyChord>Remove one entry from Recent
recent_clear: Vec<KeyChord>Clear all entries in Recent
install_move_up: Vec<KeyChord>Key chords to move selection up in install list.
install_move_down: Vec<KeyChord>Key chords to move selection down in install list.
install_confirm: Vec<KeyChord>Key chords to confirm and execute install/remove operation.
install_remove: Vec<KeyChord>Key chords to remove item from install list.
install_clear: Vec<KeyChord>Key chords to clear install list.
install_find: Vec<KeyChord>Key chords to find/search in install list.
install_to_search: Vec<KeyChord>Key chords to move focus from install to search pane.
install_focus_left: Vec<KeyChord>Key chords to move focus left from install pane.
news_mark_read: Vec<KeyChord>Mark currently listed News items as read (without opening URL)
news_mark_all_read: Vec<KeyChord>Mark all listed News items as read
news_mark_read_feed: Vec<KeyChord>Mark selected News Feed item as read.
news_mark_unread_feed: Vec<KeyChord>Mark selected News Feed item as unread.
news_toggle_read_feed: Vec<KeyChord>Toggle read/unread for selected News Feed item.